pub struct PlanConfig {
pub file: String,
}Expand description
Plan file configuration (v0.14.12).
Allows projects to name their plan file something other than PLAN.md.
[plan]
file = "ROADMAP.md"Fields
file: StringName of the plan file relative to workspace root. Default: “PLAN.md”.