pub struct ExternalVcsAdapter { /* private fields */ }Expand description
SourceAdapter that delegates all operations to an external plugin process.
Implementations
Sourceimpl ExternalVcsAdapter
impl ExternalVcsAdapter
Sourcepub fn new(
manifest: &VcsPluginManifest,
work_dir: impl Into<PathBuf>,
ta_version: &str,
) -> Result<Self>
pub fn new( manifest: &VcsPluginManifest, work_dir: impl Into<PathBuf>, ta_version: &str, ) -> Result<Self>
Create a new adapter and perform the initial handshake.
Returns SubmitError::ConfigError if the plugin is not found,
the handshake fails, or protocol versions are incompatible.
Sourcepub fn detect_with_plugin(
manifest: &VcsPluginManifest,
project_root: &Path,
ta_version: &str,
) -> bool
pub fn detect_with_plugin( manifest: &VcsPluginManifest, project_root: &Path, ta_version: &str, ) -> bool
Auto-detect using the plugin’s detect method.