NoneAdapter

Struct NoneAdapter 

pub struct NoneAdapter;
Fallback adapter that performs no VCS operations

This adapter maintains backwards compatibility with workflows that don’t use version control integration. It’s selected automatically when no workflow config exists or when adapter = “none”.

Implementations

Source

impl NoneAdapter

pub fn new() -> Self