pub struct NoneAdapter;Expand description
Fallback adapter that performs no VCS operations
This adapter maintains backwards compatibility with workflows that don’t use version control integration. It’s selected automatically when no workflow config exists or when adapter = “none”.
Implementations
Sourceimpl NoneAdapter
impl NoneAdapter